@@ -550,7 +550,7 @@ T ExtractorPostprocessorPrivate::processReservation(T res) const
 {
     res.setUnderName(processPerson(res.underName().template value<Person>()));
     res.setPotentialAction(processActions(res.potentialAction()));
-    res.setReservationNumber(res.reservationNumber().trimmed());
+    res.setReservationNumber(res.reservationNumber().simplified());
     res.setProgramMembershipUsed(processProgramMembership(res.programMembershipUsed()));
     res.setPriceCurrency(processCurrency(res.priceCurrency()));
 
