@@ -4,16 +4,19 @@
 */
 
 function parseBoardingPass(pdf, node, triggerNode) {
-    var res = triggerNode.result[0];
     const page = pdf.pages[triggerNode.location];
-    const timesText = page.textInRect(0.0, 0.0, 0.5, 0.5, 180);
-    let times = timesText.match(/\n(?:\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)/);
-    if (!times) {
-        times = timesText.match(/\n(?:\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)/);
-    }
-    res.reservationFor.boardingTime = JsonLd.toDateTime(times[1], "hh:mm", "en");
-    res.reservationFor.departureTime = JsonLd.toDateTime(times[2], "hh:mm", "en");
-    res.reservationFor.arrivalTime = JsonLd.toDateTime(times[3], "hh:mm", "en");
+    let res = triggerNode.result[0];
+
+    const topRight = page.textInRect(0.5, 0.0, 1.0, 0.5);
+    const depTimes = topRight.match(/(\d\d:\d\d).*(\d\d:\d\d)/);
+    res.reservationFor.boardingTime = JsonLd.toDateTime(depTimes[1], "hh:mm", "en");
+    res.reservationFor.departureTime = JsonLd.toDateTime(depTimes[2], "hh:mm", "en");
+
+    const bottomRight = page.textInRect(0.0, 0.0, 0.5, 0.5, 180);
+    const times = bottomRight.match(/(\d\d:\d\d)/g);
+    if (times.length > 3 && times[times.length - 1] != depTimes[2])
+        res.reservationFor.arrivalTime = JsonLd.toDateTime(times[times.length -1], "hh:mm", "en");
+
     return res;
 }
 
